==> ejc-zdsstore-api-3.0.0-20231224.063958-32-sources.jar: com/ejianc/business/zdsstore/vo/AllotOutDetailVO.java <==
package com.ejianc.business.zdsstore.vo;

import java.math.*;

import com.ejianc.business.tools.refer.annotation.ReferJsonField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 调拨出库子表
 * 
 * @author generator
 * 
 */
public class AllotOutDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    

    private Long allocatId; // 主表id
    @ReferJsonField(referCode = "MaterialCategory001",referFields = "code",resultFields = "materialTypeCode")
    private Long materialCategoryId; // 物资分类id
    private String materialTypeCode;
    private String materialCategoryName; // 物资分类名称
    @ReferJsonField(referCode = "Material001",referFields = "code",resultFields = "materialCode")
    private Long materialId; // 物资id
    private String materialCode;
    private String materialName; // 物资名称
    private String materialSpec; // 规格型号
    private Long materialUnitId; // 物资计量单位id
    private String materialUnit; // 物资计量单位
    private BigDecimal surplusNum; // 剩余可用数量
    private BigDecimal allocatNum; // 调拨数量
    private BigDecimal allocatPrice; // 调拨单价
    private BigDecimal allocatTaxPrice; // 调拨单价（有税）
    private BigDecimal allocatTaxRate; // 调拨税率
    private BigDecimal allocatMny; // 调拨金额
    private BigDecimal allocatTaxMny; // 调拨单价（有税）
    private BigDecimal allocatTax; // 调拨税额
    private BigDecimal inStoreAveragePrice; // 入库均价
    private BigDecimal inStoreTax; // 入库税额
    private BigDecimal inStoreMny; // 入库金额
    private BigDecimal inStoreTaxMny; // 入库金额（有税）
    private String memo; // 备注
    private BigDecimal inStoreTaxRate;//入库税率
    private BigDecimal  allotDiffMny;//调拨差额(无税)
    private BigDecimal  allotDiffTaxMny;//调拨差额
    private Long wbsId; // 核算对象id
    private String wbsCode; // 核算对象code
    private String wbsName; // 核算对象name
    private Long subjectId; // 成本科目id
    private String subjectCode; // 成本科目code
    private String subjectName; // 成本科目name
    private Long brandId; //品牌主键
    private String brandName; // 品牌
    private String assetValue; // 资产价值
    private String productCode; // 产品代码
    private String detailStoreName; // 仓库名称
    private Long detailStoreId;//仓库id

    public Long getDetailStoreId() {
        return detailStoreId;
    }

    public void setDetailStoreId(Long detailStoreId) {
        this.detailStoreId = detailStoreId;
    }

    public String getDetailStoreName() {
        return detailStoreName;
    }

    public void setDetailStoreName(String detailStoreName) {
        this.detailStoreName = detailStoreName;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public Long getBrandId() {
        return brandId;
    }
    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }
    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public String getAssetValue() {
        return assetValue;
    }

    public void setAssetValue(String assetValue) {
        this.assetValue = assetValue;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public Long getAllocatId() {
        return allocatId;
    }

    public void setAllocatId(Long allocatId) {
        this.allocatId = allocatId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnit() {
        return materialUnit;
    }

    public void setMaterialUnit(String materialUnit) {
        this.materialUnit = materialUnit;
    }
    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }
    public BigDecimal getAllocatNum() {
        return allocatNum;
    }

    public void setAllocatNum(BigDecimal allocatNum) {
        this.allocatNum = allocatNum;
    }
    public BigDecimal getAllocatPrice() {
        return allocatPrice;
    }

    public void setAllocatPrice(BigDecimal allocatPrice) {
        this.allocatPrice = allocatPrice;
    }
    public BigDecimal getAllocatTaxPrice() {
        return allocatTaxPrice;
    }

    public void setAllocatTaxPrice(BigDecimal allocatTaxPrice) {
        this.allocatTaxPrice = allocatTaxPrice;
    }

    public BigDecimal getAllocatTaxRate() {
        return allocatTaxRate;
    }

    public void setAllocatTaxRate(BigDecimal allocatTaxRate) {
        this.allocatTaxRate = allocatTaxRate;
    }

    public BigDecimal getAllocatMny() {
        return allocatMny;
    }

    public void setAllocatMny(BigDecimal allocatMny) {
        this.allocatMny = allocatMny;
    }
    public BigDecimal getAllocatTaxMny() {
        return allocatTaxMny;
    }

    public void setAllocatTaxMny(BigDecimal allocatTaxMny) {
        this.allocatTaxMny = allocatTaxMny;
    }
    public BigDecimal getAllocatTax() {
        return allocatTax;
    }

    public void setAllocatTax(BigDecimal allocatTax) {
        this.allocatTax = allocatTax;
    }
    public BigDecimal getInStoreAveragePrice() {
        return inStoreAveragePrice;
    }

    public void setInStoreAveragePrice(BigDecimal inStoreAveragePrice) {
        this.inStoreAveragePrice = inStoreAveragePrice;
    }
    public BigDecimal getInStoreTax() {
        return inStoreTax;
    }

    public void setInStoreTax(BigDecimal inStoreTax) {
        this.inStoreTax = inStoreTax;
    }
    public BigDecimal getInStoreMny() {
        return inStoreMny;
    }

    public void setInStoreMny(BigDecimal inStoreMny) {
        this.inStoreMny = inStoreMny;
    }

    public BigDecimal getInStoreTaxMny() {
        return inStoreTaxMny;
    }

    public void setInStoreTaxMny(BigDecimal inStoreTaxMny) {
        this.inStoreTaxMny = inStoreTaxMny;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getInStoreTaxRate() {
        return inStoreTaxRate;
    }

    public void setInStoreTaxRate(BigDecimal inStoreTaxRate) {
        this.inStoreTaxRate = inStoreTaxRate;
    }

    public BigDecimal getAllotDiffMny() {
        return allotDiffMny;
    }

    public void setAllotDiffMny(BigDecimal allotDiffMny) {
        this.allotDiffMny = allotDiffMny;
    }

    public BigDecimal getAllotDiffTaxMny() {
        return allotDiffTaxMny;
    }

    public void setAllotDiffTaxMny(BigDecimal allotDiffTaxMny) {
        this.allotDiffTaxMny = allotDiffTaxMny;
    }
    @ReferSerialTransfer(referCode = "subject-project-wbs-ref")
    public Long getWbsId() {
        return wbsId;
    }
    @ReferDeserialTransfer
    public void setWbsId(Long wbsId) {
        this.wbsId = wbsId;
    }

    public String getWbsCode() {
        return wbsCode;
    }

    public void setWbsCode(String wbsCode) {
        this.wbsCode = wbsCode;
    }

    public String getWbsName() {
        return wbsName;
    }

    public void setWbsName(String wbsName) {
        this.wbsName = wbsName;
    }
    @ReferSerialTransfer(referCode = "subject-project-org-ref")
    public Long getSubjectId() {
        return subjectId;
    }
    @ReferDeserialTransfer
    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }

    public String getSubjectCode() {
        return subjectCode;
    }

    public void setSubjectCode(String subjectCode) {
        this.subjectCode = subjectCode;
    }

    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }

}

==> ejc-zdsstore-api-3.0.0-20241120.150938-234-sources.jar: com/ejianc/business/zdsstore/vo/AllotOutDetailVO.java <==
package com.ejianc.business.zdsstore.vo;

import java.math.*;

import com.ejianc.business.tools.refer.annotation.ReferJsonField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 调拨出库子表
 * 
 * @author generator
 * 
 */
public class AllotOutDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    

    private Long allocatId; // 主表id
    @ReferJsonField(referCode = "MaterialCategory001",referFields = "code",resultFields = "materialTypeCode")
    private Long materialCategoryId; // 物资分类id
    private String materialCategoryCode;
    private String materialCategoryName; // 物资分类名称
    @ReferJsonField(referCode = "Material001",referFields = "code",resultFields = "materialCode")
    private Long materialId; // 物资id
    private String materialCode;
    private String materialName; // 物资名称
    private String materialSpec; // 规格型号
    private Long materialUnitId; // 物资计量单位id
    private String materialUnit; // 物资计量单位
    private BigDecimal surplusNum; // 剩余可用数量
    private BigDecimal allocatNum; // 调拨数量
    private BigDecimal allocatPrice; // 调拨单价
    private BigDecimal allocatTaxPrice; // 调拨单价（有税）
    private BigDecimal allocatTaxRate; // 调拨税率
    private BigDecimal allocatMny; // 调拨金额
    private BigDecimal allocatTaxMny; // 调拨单价（有税）
    private BigDecimal allocatTax; // 调拨税额
    private BigDecimal inStoreAveragePrice; // 入库均价
    private BigDecimal inStoreTax; // 入库税额
    private BigDecimal inStoreMny; // 入库金额
    private BigDecimal inStoreTaxMny; // 入库金额（有税）
    private String memo; // 备注
    private BigDecimal inStoreTaxRate;//入库税率
    private BigDecimal  allotDiffMny;//调拨差额(无税)
    private BigDecimal  allotDiffTaxMny;//调拨差额
    private Long wbsId; // 核算对象id
    private String wbsCode; // 核算对象code
    private String wbsName; // 核算对象name
    private Long subjectId; // 成本科目id
    private String subjectCode; // 成本科目code
    private String subjectName; // 成本科目name
    private Long brandId; //品牌主键
    private String brandName; // 品牌
    private BigDecimal assetValue; // 资产价值
    private String productCode; // 产品代码
    private String detailStoreName; // 仓库名称
    private Long detailStoreId;//仓库id

    public String getMaterialCategoryCode() {
        return materialCategoryCode;
    }

    public void setMaterialCategoryCode(String materialCategoryCode) {
        this.materialCategoryCode = materialCategoryCode;
    }

    public Long getDetailStoreId() {
        return detailStoreId;
    }

    public void setDetailStoreId(Long detailStoreId) {
        this.detailStoreId = detailStoreId;
    }

    public String getDetailStoreName() {
        return detailStoreName;
    }

    public void setDetailStoreName(String detailStoreName) {
        this.detailStoreName = detailStoreName;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public Long getBrandId() {
        return brandId;
    }
    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }
    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public BigDecimal getAssetValue() {
        return assetValue;
    }

    public void setAssetValue(BigDecimal assetValue) {
        this.assetValue = assetValue;
    }



    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public Long getAllocatId() {
        return allocatId;
    }

    public void setAllocatId(Long allocatId) {
        this.allocatId = allocatId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnit() {
        return materialUnit;
    }

    public void setMaterialUnit(String materialUnit) {
        this.materialUnit = materialUnit;
    }
    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }
    public BigDecimal getAllocatNum() {
        return allocatNum;
    }

    public void setAllocatNum(BigDecimal allocatNum) {
        this.allocatNum = allocatNum;
    }
    public BigDecimal getAllocatPrice() {
        return allocatPrice;
    }

    public void setAllocatPrice(BigDecimal allocatPrice) {
        this.allocatPrice = allocatPrice;
    }
    public BigDecimal getAllocatTaxPrice() {
        return allocatTaxPrice;
    }

    public void setAllocatTaxPrice(BigDecimal allocatTaxPrice) {
        this.allocatTaxPrice = allocatTaxPrice;
    }

    public BigDecimal getAllocatTaxRate() {
        return allocatTaxRate;
    }

    public void setAllocatTaxRate(BigDecimal allocatTaxRate) {
        this.allocatTaxRate = allocatTaxRate;
    }

    public BigDecimal getAllocatMny() {
        return allocatMny;
    }

    public void setAllocatMny(BigDecimal allocatMny) {
        this.allocatMny = allocatMny;
    }
    public BigDecimal getAllocatTaxMny() {
        return allocatTaxMny;
    }

    public void setAllocatTaxMny(BigDecimal allocatTaxMny) {
        this.allocatTaxMny = allocatTaxMny;
    }
    public BigDecimal getAllocatTax() {
        return allocatTax;
    }

    public void setAllocatTax(BigDecimal allocatTax) {
        this.allocatTax = allocatTax;
    }
    public BigDecimal getInStoreAveragePrice() {
        return inStoreAveragePrice;
    }

    public void setInStoreAveragePrice(BigDecimal inStoreAveragePrice) {
        this.inStoreAveragePrice = inStoreAveragePrice;
    }
    public BigDecimal getInStoreTax() {
        return inStoreTax;
    }

    public void setInStoreTax(BigDecimal inStoreTax) {
        this.inStoreTax = inStoreTax;
    }
    public BigDecimal getInStoreMny() {
        return inStoreMny;
    }

    public void setInStoreMny(BigDecimal inStoreMny) {
        this.inStoreMny = inStoreMny;
    }

    public BigDecimal getInStoreTaxMny() {
        return inStoreTaxMny;
    }

    public void setInStoreTaxMny(BigDecimal inStoreTaxMny) {
        this.inStoreTaxMny = inStoreTaxMny;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getInStoreTaxRate() {
        return inStoreTaxRate;
    }

    public void setInStoreTaxRate(BigDecimal inStoreTaxRate) {
        this.inStoreTaxRate = inStoreTaxRate;
    }

    public BigDecimal getAllotDiffMny() {
        return allotDiffMny;
    }

    public void setAllotDiffMny(BigDecimal allotDiffMny) {
        this.allotDiffMny = allotDiffMny;
    }

    public BigDecimal getAllotDiffTaxMny() {
        return allotDiffTaxMny;
    }

    public void setAllotDiffTaxMny(BigDecimal allotDiffTaxMny) {
        this.allotDiffTaxMny = allotDiffTaxMny;
    }
    @ReferSerialTransfer(referCode = "subject-project-wbs-ref")
    public Long getWbsId() {
        return wbsId;
    }
    @ReferDeserialTransfer
    public void setWbsId(Long wbsId) {
        this.wbsId = wbsId;
    }

    public String getWbsCode() {
        return wbsCode;
    }

    public void setWbsCode(String wbsCode) {
        this.wbsCode = wbsCode;
    }

    public String getWbsName() {
        return wbsName;
    }

    public void setWbsName(String wbsName) {
        this.wbsName = wbsName;
    }
    @ReferSerialTransfer(referCode = "subject-project-org-ref")
    public Long getSubjectId() {
        return subjectId;
    }
    @ReferDeserialTransfer
    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }

    public String getSubjectCode() {
        return subjectCode;
    }

    public void setSubjectCode(String subjectCode) {
        this.subjectCode = subjectCode;
    }

    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }

}
